; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands are given below. Delete, add, or modify as you wish.


;-| Super Motions |--------------------------------------------------------
[Command]
name = "QCF_PP"
command = ~D, DF, F, x+y

[Command]
name = "QCF_PP"
command = ~D, DF, F, x+z

[Command]
name = "QCF_PP"
command = ~D, DF, F, y+z

[Command]
name = "QCF_KK"
command = ~D, DF, F, a+b

[Command]
name = "QCF_KK"
command = ~D, DF, F, a+c

[Command]
name = "QCF_KK"
command = ~D, DF, F, b+c

[Command]
name = "QCF2_a"
command = ~D, DF, F, D, DF, F, a
time = 20

[Command]
name = "QCF2_b"
command = ~D, DF, F, D, DF, F, b
time = 20

[Command]
name = "QCF2_c"
command = ~D, DF, F, D, DF, F, c
time = 20

[Command]
name = "shungoku"
command = x, x, F, a, z
time = 35

;-| Special Motions |------------------------------------------------------
[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "QCF_z"
command = ~D, DF, F, z

[Command]
name = "QCF_a"
command = ~D, DF, F, a

[Command]
name = "QCF_b"
command = ~D, DF, F, b

[Command]
name = "QCF_c"
command = ~D, DF, F, c

[Command]
name = "QCB_a"
command = ~D, DB, B, a

[Command]
name = "QCB_b"
command = ~D, DB, B, b

[Command]
name = "QCB_c"
command = ~D, DB, B, c

[Command]
name = "DP_a"
command = ~F, D, DF, a

[Command]
name = "DP_b"
command = ~F, D, DF, b

[Command]
name = "DP_c"
command = ~F, D, DF, c

[Command]
name = "DP_x"
command = ~F, D, DF, x

[Command]
name = "DP_y"
command = ~F, D, DF, y

[Command]
name = "DP_z"
command = ~F, D, DF, z

[Command]
name = "HCF_x"
command = ~B, DB, D, DF, F, x

[Command]
name = "HCF_y"
command = ~B, DB, D, DF, F, y

[Command]
name = "HCF_z"
command = ~B, DB, D, DF, F, z

[Command]
name = "HCF_a"
command = ~B, DB, D, DF, F, a

[Command]
name = "HCF_b"
command = ~B, DB, D, DF, F, b

[Command]
name = "HCF_c"
command = ~B, DB, D, DF, F, c

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

[Command]
name = "PPP"
command = x+y+z
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;-| Hold Button |--------------------------------------------------------------
[Command]
name = "holda"
command = /a
time = 1

[Command]
name = "holdb"
command = /b
time = 1

[Command]
name = "holdc"
command = /c
time = 1

[Command]
name = "holdx"
command = /x
time = 1

[Command]
name = "holdy"
command = /y
time = 1

[Command]
name = "holdz"
command = /z
time = 1

;-| Custom |--------------------------------------------------------------
[Command]
name = "U"
command = U
time = 1

[Command]
name = "DU"
command = ~D, $U
time = 10

;-| AI |--------------------------------------------------------------
[Command]
name = "AI1"
command = U,D,B,F,U,D,B,F,b,b,a,a,s
time = 0

[Command]
name = "AI2"
command = U,D,U,D,U,D,U,D,U,D,U,D,a+b+c+x+y+z
time = 0

[Command]
name = "AI3"
command = U,F,B,D,B,F,U,x,x,x,y,y,y,z,z,z
time = 0

[Command]
name = "AI4"
command = x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x
time = 0

[Command]
name = "AI5"
command = y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y
time = 0

[Command]
name = "AI6"
command = z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z
time = 0

[Command]
name = "AI7"
command = x+y+z,x+y+z,x+y+z,x+y+z,x+y+z,x+y+z,x+y+z
time = 0

[Command]
name = "AI8"
command = a+b+c,a+b+c,a+b+c,a+b+c,a+b+c,a+b+c,a+b+c
time = 0

[Command]
name = "AI9"
command = y,a,B,B,a,D,a,B,B,a
time = 0

[Command]
name = "AI10"
command = c,U,B,B,y,B,U,D,D,y
time = 0

[Command]
name = "AI11"
command = x,x,x,x
time = 0

[Command]
name = "AI12"
command = y,y,y,y
time = 0

[Command]
name = "AI13"
command = z,z,z,z
time = 0

[Command]
name = "AI14"
command = a,a,a,a
time = 0

[Command]
name = "AI15"
command = b,b,b,b
time = 0

[Command]
name = "AI16"
command = c,c,c,c
time = 0

[Command]
name = "AI17"
command = U,x,U,x
time = 0

[Command]
name = "AI18"
command = D,x,D,x
time = 0

[Command]
name = "AI19"
command = B,x,B,x
time = 0

[Command]
name = "AI20"
command = F,x,F,x
time = 0

[Command]
name = "KonamiCode"
command = U,U,D,D,B,F,B,F,b,a,s
time = 0

[Command]
name = "aXOR"
command = a
time = 1

[Command]
name = "bXOR"
command = b
time = 1

[Command]
name = "cXOR"
command = c
time = 1

[Command]
name = "xXOR"
command = x
time = 1

[Command]
name = "yXOR"
command = y
time = 1

[Command]
name = "zXOR"
command = z
time = 1

[Command]
name = "startXOR"
command = s
time = 1

[Command]
name = "holdfwdXOR"
command = /$F
time = 1

[Command]
name = "holdbackXOR"
command = /$B
time = 1

[Command]
name = "holdupXOR"
command = /$U
time = 1

[Command]
name = "holddownXOR"
command = /$D
time = 1

[Command]
name = "holdxXOR"
command = /x
time = 1

[Command]
name = "holdyXOR"
command = /y
time = 1

[Command]
name = "holdzXOR"
command = /z
time = 1

[Command]
name = "holdaXOR"
command = /a
time = 1

[Command]
name = "holdbXOR"
command = /b
time = 1

[Command]
name = "holdcXOR"
command = /c
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
; AI
;===========================================================================
;---------------------------------------------------------------------------
;Activate AI
[State -1, Activate AI]
type = VarSet
triggerall = var(59) = 0
triggerall = var(57) != 1 ; Difficulty level not set to No AI
triggerall = !isHelper
trigger1 = IsHomeTeam
trigger1 = TeamSide = 2
trigger2 = command = "KonamiCode"
trigger3 = command = "AI1"
trigger4 = command = "AI2"
trigger5 = command = "AI3"
trigger6 = command = "AI4"
trigger7 = command = "AI5"
trigger8 = command = "AI6"
trigger9 = command = "AI7"
trigger10 = command = "AI8"
trigger11 = command = "AI9"
trigger12 = command = "AI10"
trigger13 = command = "AI11"
trigger14 = command = "AI12"
trigger15 = command = "AI13"
trigger16 = command = "AI14"
trigger17 = command = "AI15"
trigger18 = command = "AI16"
trigger19 = command = "AI17"
trigger20 = command = "AI18"
trigger21 = command = "AI19"
trigger22 = command = "AI20"
trigger23 = command = "a" ^^ command = "aXOR"
trigger24 = command = "b" ^^ command = "bXOR"
trigger25 = command = "c" ^^ command = "cXOR"
trigger26 = command = "x" ^^ command = "xXOR"
trigger27 = command = "y" ^^ command = "yXOR"
trigger28 = command = "z" ^^ command = "zXOR"
trigger29 = command = "start" ^^ command = "startXOR"
trigger30 = command = "holdfwd" ^^ command = "holdfwdXOR"
trigger31 = command = "holdback" ^^ command = "holdbackXOR"
trigger32 = command = "holdup" ^^ command = "holdupXOR"
trigger33 = command = "holddown" ^^ command = "holddownXOR"
trigger34 = command = "holda" ^^ command = "holdaXOR"
trigger35 = command = "holdb" ^^ command = "holdbXOR"
trigger36 = command = "holdc" ^^ command = "holdcXOR"
trigger37 = command = "holdx" ^^ command = "holdxXOR"
trigger38 = command = "holdy" ^^ command = "holdyXOR"
trigger39 = command = "holdz" ^^ command = "holdzXOR"
v = 59
value = 1

;---------------------------------------------------------------------------
;Activate AI
[State -1, Activate AI]
type = VarSet
triggerall = var(59) = 2
trigger1 = RoundState < 3
v = 59
value = 1

;---------------------------------------------------------------------------
;Deactivate AI
[State -1, Deactivate AI]
type = VarSet
triggerall = var(59) != 0
trigger1 = RoundState >= 3
v = 59
value = 2

;---------------------------------------------------------------------------
;Liedown AI
[State -1, Liedown AI]
type = VarSet
triggerall = var(59) = 1
trigger1 = p2statetype = L
trigger2 = p2stateno = [5050,5079]
v = 59
value = 4

;---------------------------------------------------------------------------
;Liedown AI Off
[State -1, Liedown AI Off]
type = VarSet
triggerall = var(59) = 4
trigger1 = p2statetype != L
trigger1 = p2stateno != [5050,5079]
v = 59
value = 1

;---------------------------------------------------------------------------
;Check Miss AI Begin Attack
[State -1, Check Miss AI Begin Attack]
type = VarSet
triggerall = var(59) != 0
triggerall = var(58) <= 0
trigger1 = movetype = A
v = 58
value = stateno

;---------------------------------------------------------------------------
;Check Miss AI Hit
[State -1, Check Miss AI Hit]
type = VarSet
triggerall = var(59) != 0
triggerall = var(58) != 0
trigger1 = movehit
trigger2 = movetype = I
trigger2 = random < 10
trigger3 = stateno = [150,159]
v = 58
value = 0

;---------------------------------------------------------------------------
;Check Miss AI End Attack
[State -1, Check Miss AI End Attack]
type = VarSet
triggerall = var(59) != 0
triggerall = var(58) > 0
trigger1 = ctrl = 1
v = 58
value = var(58)*(-1)

;===========================================================================
; AI Guard
;===========================================================================
;---------------------------------------------------------------------------
;AI Guard (Standing)
[State -1, AI Guard (Standing)]
type = ChangeState
value = 130
triggerall = var(59) != 0
triggerall = var(57) != 2 ; Difficulty level
triggerall = statetype != A
triggerall = ctrl
triggerall = p2statetype != C
trigger1 = inguarddist

;---------------------------------------------------------------------------
;AI Guard (Crouching)
[State -1, AI Guard (Crouching)]
type = ChangeState
value = 131
triggerall = var(59) != 0
triggerall = var(57) != 2 ; Difficulty level
triggerall = statetype != A
triggerall = ctrl
triggerall = p2statetype = C
trigger1 = inguarddist

;---------------------------------------------------------------------------
;AI Guard (Air)
[State -1, AI Guard (Air)]
type = ChangeState
value = 132
triggerall = var(59) != 0
triggerall = var(57) != 2 ; Difficulty level
triggerall = statetype = A
triggerall = ctrl
trigger1 = inguarddist

;---------------------------------------------------------------------------
;AI Guard Push (Stand)
[State -1, AI Guard Push (Stand)]
type = ChangeState
value = 160
triggerall = var(59) != 0
triggerall = var(57) != 2 ; Difficulty level
triggerall = (var(57) = 4) || ((random < 250) && Time <= 1) ; Difficulty level
trigger1 = command != "holddown"
trigger1 = statetype = S
trigger1 = stateno = 150
ignorehitpause = 1

;---------------------------------------------------------------------------
;AI Guard Push (Crouch)
[State -1, AI Guard Push (Crouch)]
type = ChangeState
value = 161
triggerall = var(59) != 0
triggerall = var(57) != 2 ; Difficulty level
triggerall = (var(57) = 4) || ((random < 250) && Time <= 1) ; Difficulty level
trigger1 = statetype = C
trigger1 = stateno = 152
ignorehitpause = 1

;---------------------------------------------------------------------------
;AI Guard Push (Air)
[State -1, AI Guard Push (Air)]
type = ChangeState
value = 162
triggerall = var(59) != 0
triggerall = var(57) != 2 ; Difficulty level
triggerall = (var(57) = 4) || ((random < 250) && Time <= 1) ; Difficulty level
trigger1 = statetype = A
trigger1 = stateno = 154
ignorehitpause = 1

;===========================================================================
; AI Throw
;===========================================================================
;---------------------------------------------------------------------------
;AI Rising Throw
[State -1, AI Rising Throw]
type = ChangeState
value = 800
triggerall = var(59) = 1
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = random < 500
trigger1 = p2bodydist X < 6
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger1 = -var(58) != 800

;===========================================================================
; AI Combo
;===========================================================================
;---------------------------------------------------------------------------
;AI Combo Crouching Light Kick
[State -1, AI Combo Crouching Light Kick]
type = ChangeState
value = 430
triggerall = var(59) = 1
trigger1 = p2bodydist X < 45
trigger1 = p2dist y = [-10,10]
trigger1 = random < 500
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;AI Combo Crouching Medium Punch
[State -1, AI Combo Crouching Medium Punch]
type = ChangeState
value = 410
triggerall = var(59) = 1
trigger1 = (stateno = 430) && MoveContact

;---------------------------------------------------------------------------
;AI Standing Medium Kick
[State -1, AI Standing Medium Kick]
type = ChangeState
value = 240
triggerall = var(59) = 1
trigger1 = (stateno = 410) && MoveContact

;---------------------------------------------------------------------------
;AI Standing Strong Kick
[State -1, AI Standing Strong Kick]
type = ChangeState
value = 250
triggerall = var(59) = 1
trigger1 = (stateno = 240) && MoveContact

;---------------------------------------------------------------------------
;AI Combo Crouching Strong Punch
[State -1, AI Combo Crouching Strong Punch]
type = ChangeState
value = 420
triggerall = var(59) = 1
trigger1 = (stateno = 240) && MoveContact

;===========================================================================
; AI Jump Aerial Rave
;===========================================================================
;---------------------------------------------------------------------------
;AI Aerial Rave On
[State -1, AI Aerial Rave On]
type = VarSet
triggerall = var(59) = 1
triggerall = statetype != A
trigger1 = stateno = 420
trigger1 = MoveHit > 8
trigger2 = stateno = 250
trigger2 = MoveHit > 8
v = 59
value = 3

;---------------------------------------------------------------------------
;Super Jump
[State -1, Super Jump]
type = ChangeState
value = 65
triggerall = var(59) != 0
triggerall = Pos Y = 0
trigger1 = (stateno = 250) && MoveHit > 8
trigger2 = (stateno = 420) && MoveHit > 8

;---------------------------------------------------------------------------
;AI Jump Light Punch
[State -1, AI Jump Light Punch]
type = ChangeState
value = 600
triggerall = var(59) = 3
trigger1 = stateno = 70
trigger1 = ctrl
trigger1 = p2bodydist X = [-40,40]
trigger1 = p2dist Y + (vel Y) = [-50,30]

;---------------------------------------------------------------------------
;AI Aerial Rave Over
[State -1, AI Aerial Rave Over]
type = VarSet
triggerall = var(59) = 3
trigger1 = statetype != A
trigger1 = stateno != [65,70]
trigger2 = stateno = 600
v = 59
value = 1

;---------------------------------------------------------------------------
;AI Jump Light Kick
[State -1, AI Jump Light Kick]
type = ChangeState
value = 630
triggerall = var(59) = 1
trigger1 = (stateno = 600) && MoveContact

;---------------------------------------------------------------------------
;AI Jump Medium Punch
[State -1, AI Jump Medium Punch]
type = ChangeState
value = 610
triggerall = var(59) = 1
trigger1 = (stateno = 630) && MoveContact

;---------------------------------------------------------------------------
;AI Jump Medium Kick
[State -1, AI Jump Medium Kick]
type = ChangeState
value = 640
triggerall = var(59) = 1
trigger1 = (stateno = 610) && MoveContact

;---------------------------------------------------------------------------
;AI Jump Strong Punch
[State -1, AI Jump Strong Punch]
type = ChangeState
value = 620
triggerall = var(59) = 1
trigger1 = (stateno = 640) && MoveContact

;---------------------------------------------------------------------------
;AI Jump Strong Kick
[State -1, AI Jump Strong Kick]
type = ChangeState
value = 650
triggerall = var(59) = 1
trigger1 = (stateno = 640) && MoveContact

;===========================================================================
; AI Super Moves
;===========================================================================
;---------------------------------------------------------------------------
;AI Good Night Sugah
[State -1, AI Good Night Sugah]
type = ChangeState
value = 3000
triggerall = var(59) = 1
triggerall = statetype = S
triggerall = power >= 1000
triggerall = ctrl
trigger1 = command = "QCF_PP"

;===========================================================================
; AI Special Moves
;===========================================================================
;---------------------------------------------------------------------------
;AI Power Drain Kiss
[State -1, AI Kiss]
type = ChangeState
value = 1000
triggerall = var(59) = 1
triggerall = statetype != C
triggerall = ctrl
trigger1 = p2bodydist X < 150
trigger1 = p2dist y = [-50,10]
trigger1 = random < 25

;---------------------------------------------------------------------------
;AI Rising Repeating Punch (Weak Punch)
[State -1, AI Repeating Punch]
type = ChangeState
value = 1020
triggerall = var(59) = 1
triggerall = statetype = C
triggerall = ctrl
trigger1 = p2bodydist X < 60
trigger1 = p2dist y = [-50,10]
trigger1 = random < 5

;---------------------------------------------------------------------------
;AI Rising Repeating Punch (Continue Punching)
[State -1, AI Repeating Punch]
type = VarSet
v = 4
value = 1
triggerall = var(59) = 1
triggerall = MoveHit
trigger1 = stateno = 1020 && animelem = 7, >= 0
trigger2 = stateno = 1021 && animelem = 2, >= 3
trigger3 = stateno = 1022 && animelem = 3, >= 3

;---------------------------------------------------------------------------
;AI Dive (Weak Kick)
;[State -1, AI Dive]
;type = ChangeState
;value = 1030
;triggerall = var(59) = 1
;trigger1 = command = "DP_a"
;trigger1 = statetype = C
;trigger1 = ctrl

;---------------------------------------------------------------------------
;AI Dive (Medium Kick)
;[State -1, AI Dive]
;type = ChangeState
;value = 1031
;triggerall = var(59) = 1
;trigger1 = command = "DP_b"
;trigger1 = statetype = C
;trigger1 = ctrl

;---------------------------------------------------------------------------
;AI Dive (Strong Kick)
;[State -1, AI Dive]
;type = ChangeState
;value = 1032
;triggerall = var(59) = 1
;trigger1 = command = "DP_c"
;trigger1 = statetype = C
;trigger1 = ctrl

;---------------------------------------------------------------------------
;AI Repeating Punch (Weak Punch)
[State -1, AI Repeating Punch]
type = ChangeState
value = 1010
triggerall = var(59) = 1
trigger1 = p2bodydist X < 100
trigger1 = p2dist y = [-50,10]
trigger1 = random < 15
trigger1 = statetype != C
trigger1 = ctrl

;---------------------------------------------------------------------------
;AI Repeating Punch (Medium Punch)
[State -1, AI Repeating Punch]
type = ChangeState
value = 1011
triggerall = var(59) = 1
trigger1 = p2bodydist X < 150
trigger1 = p2dist y = [-50,10]
trigger1 = random < 15
trigger1 = statetype != C
trigger1 = ctrl

;---------------------------------------------------------------------------
;AI Repeating Punch (Strong Punch)
[State -1, AI Repeating Punch]
type = ChangeState
value = 1012
triggerall = var(59) = 1
trigger1 = p2bodydist X < 200
trigger1 = p2dist y = [-50,10]
trigger1 = random < 15
trigger1 = statetype != C
trigger1 = ctrl

;===========================================================================
; AI Basic Moves
;===========================================================================
;---------------------------------------------------------------------------
;AI Stand Light Punch
[State -1, AI Stand Light Punch]
type = ChangeState
value = 200
triggerall = var(59) = 1
trigger1 = p2bodydist X < 45
trigger1 = p2dist y = [-50,10]
trigger1 = random < 200
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;AI Stand Medium Punch
[State -1, AI Stand Medium Punch]
type = ChangeState
value = 210
triggerall = var(59) = 1
trigger1 = p2bodydist X < 55
trigger1 = p2dist y = [-50,10]
trigger1 = random < 200
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;AI Stand Strong Punch
[State -1, AI Stand Strong Punch]
type = ChangeState
value = 220
triggerall = var(59) = 1
trigger1 = p2bodydist X < 90
trigger1 = p2dist y = [-50,10]
trigger1 = random < 300
trigger1 = -var(58) != 220
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;AI Stand Light Kick
[State -1, AI Stand Light Kick]
type = ChangeState
value = 230
triggerall = var(59) = 1
trigger1 = p2bodydist X < 45
trigger1 = p2dist y = [-50,10]
trigger1 = random < 200
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;AI Standing Medium Kick
[State -1, AI Standing Medium Kick]
type = ChangeState
value = 240
triggerall = var(59) = 1
trigger1 = p2bodydist X < -55
trigger1 = p2dist y = [-50,10]
trigger1 = random < 200
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;AI Standing Strong Kick
[State -1, AI Standing Strong Kick]
type = ChangeState
value = 250
triggerall = var(59) = 1
trigger1 = p2bodydist X < -60
trigger1 = p2dist y = [-50,10]
trigger1 = random < 200
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;AI Taunt
[State -1, AI Taunt]
type = ChangeState
value = 195
triggerall = var(59) = 1
triggerall = var(57) = 2 ;Difficulty normal
triggerall = command = "start"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;AI Crouching Light Punch
[State -1, AI Crouching Light Punch]
type = ChangeState
value = 400
triggerall = var(59) = 1
trigger1 = p2bodydist X < -35
trigger1 = p2dist y = [-30,10]
trigger1 = random < 200
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;AI Crouching Medium Punch
[State -1, AI Crouching Medium Punch]
type = ChangeState
value = 410
triggerall = var(59) = 1
trigger1 = p2bodydist X < -100
trigger1 = p2dist y = [-30,10]
trigger1 = random < 200
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;AI Crouching Strong Punch
[State -1, AI Crouching Strong Punch]
type = ChangeState
value = 420
triggerall = var(59) = 1
trigger1 = p2bodydist X < -35
trigger1 = p2dist y = [-40,10]
trigger1 = random < 200
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;AI Crouching Light Kick
[State -1, AI Crouching Light Kick]
type = ChangeState
value = 430
triggerall = var(59) = 1
trigger1 = p2bodydist X < -40
trigger1 = p2dist y = [-10,10]
trigger1 = random < 200
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;AI Crouching Medium Kick
[State -1, AI Crouching Medium Kick]
type = ChangeState
value = 440
triggerall = var(59) = 1
trigger1 = p2bodydist X < -50
trigger1 = p2dist y = [-10,10]
trigger1 = random < 200
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;AI Crouching Strong Kick
[State -1, AI Crouching Strong Kick]
type = ChangeState
value = 450
triggerall = var(59) = 1
trigger1 = p2bodydist X < -75
trigger1 = p2dist y = [-10,10]
trigger1 = random < 200
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;AI Jump Light Punch
[State -1, AI Jump Light Punch]
type = ChangeState
value = 600
triggerall = var(59) = 1
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;AI Jump Medium Punch
[State -1, AI Jump Medium Punch]
type = ChangeState
value = 610
triggerall = var(59) = 1
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600) && MoveContact
trigger3 = (stateno = 630) && MoveContact

;---------------------------------------------------------------------------
;AI Jump Strong Punch
[State -1, AI Jump Strong Punch]
type = ChangeState
value = 620
triggerall = var(59) = 1
triggerall = command = "z"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600) && MoveContact
trigger3 = (stateno = 610) && MoveContact
trigger4 = (stateno = 630) && MoveContact
trigger5 = (stateno = 640) && MoveContact

;---------------------------------------------------------------------------
;AI Jump Light Kick
[State -1, AI Jump Light Kick]
type = ChangeState
value = 630
triggerall = var(59) = 1
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600) && MoveContact

;---------------------------------------------------------------------------
;AI Jump Medium Kick
[State -1, AI Jump Medium Kick]
type = ChangeState
value = 640
triggerall = var(59) = 1
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600) && MoveContact
trigger3 = (stateno = 610) && MoveContact
trigger4 = (stateno = 630) && MoveContact

;---------------------------------------------------------------------------
;AI Dive Kick
[State -1, AI Dive Kick]
type = ChangeState
value = 655
triggerall = var(59) = 1
triggerall = command = "c"
triggerall = command = "holddown"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;AI Jump Strong Kick
[State -1, AI Jump Strong Kick]
type = ChangeState
value = 650
triggerall = var(59) = 1
triggerall = command = "c"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600) && MoveContact
trigger3 = (stateno = 610) && MoveContact
trigger4 = (stateno = 630) && MoveContact
trigger5 = (stateno = 640) && MoveContact

;===========================================================================
; AI Movement
;===========================================================================
;---------------------------------------------------------------------------
;AI Run Fwd
[State -1, AI Run Fwd]
type = ChangeState
value = 100
triggerall = var(59) = 1
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = stateno != 100
trigger1 = ctrl

;---------------------------------------------------------------------------
;AI Air Run Fwd
[State -1, AI Run Fwd]
type = ChangeState
value = 102
triggerall = var(59) = 1
trigger1 = command = "FF"
trigger1 = Pos Y <= -70
trigger1 = statetype = A
trigger1 = stateno != 102
trigger1 = ctrl

;---------------------------------------------------------------------------
;AI Run Back
[State -1, AI Run Back]
type = ChangeState
value = 105
triggerall = var(59) = 1
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = stateno != 105
trigger1 = ctrl

;---------------------------------------------------------------------------
;AI Roll
[State -1, AI Roll]
type = ChangeState
value = 1040
triggerall = var(59) = 1
triggerall = (stateno = 5101) || (stateno = 5110)
trigger1 = command = "HCF_a"
trigger2 = command = "HCF_b"
trigger3 = command = "HCF_c"
trigger4 = command = "HCF_x"
trigger5 = command = "HCF_y"
trigger6 = command = "HCF_z"

;===========================================================================
; End of AI Section
;===========================================================================

;===========================================================================
;Super Moves
;===========================================================================
;---------------------------------------------------------------------------
;Good Night Sugah
[State -1, Kiss]
type = ChangeState
value = 3000
triggerall = var(59) = 0
triggerall = statetype = S
triggerall = power >= 1000
triggerall = ctrl
trigger1 = command = "QCF_PP"

;===========================================================================
;Stolen Super Moves
;===========================================================================
;---------------------------------------------------------------------------
[State -1, Shinkuu Hadoken (Standing) (Ryu)]
type = ChangeState
value = 6010
triggerall = var(59) = 0
triggerall = var(0) = 2
triggerall = command = "QCF_KK"
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = [200,250]) || (stateno = [400,450]) ;Regular Attacks
trigger2 = movecontact = 1

;;---------------------------------------------------------------------------
;[State -1, Shinkuu Hadoken (Air) (Ryu)]
;type = ChangeState
;value = 6013
;triggerall = var(59) = 0
;triggerall = var(0) = 2
;triggerall = command = "QCF_KK"
;triggerall = power >= 1000
;trigger1 = statetype = A
;trigger1 = ctrl
;trigger2 = stateno = [600,650] ;Regular Attacks
;trigger2 = movecontact = 1

;===========================================================================
;Special Moves
;===========================================================================
;---------------------------------------------------------------------------
;Power Drain Kiss
[State -1, Kiss]
type = ChangeState
value = 1000
triggerall = var(59) = 0
triggerall = command = "QCB_a" || command = "QCB_b" || command = "QCB_c"
trigger1 = statetype != C
trigger1 = ctrl
trigger2 = stateno = [200,499]

;---------------------------------------------------------------------------
;Rising Repeating Punch (Start)
[State -1, Repeating Punch]
type = ChangeState
value = 1020
triggerall = var(59) = 0
triggerall = command = "DP_x" || command = "DP_y" || command = "DP_z"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = [200,499]

;---------------------------------------------------------------------------
;Rising Repeating Punch (Continue Punching)
[State -1, Repeating Punch]
type = VarSet
v = 4
value = 1
triggerall = var(59) = 0
triggerall = command = "x" || command = "y" || command = "z"
trigger1 = stateno = 1020 && animelem = 7, >= 0
trigger2 = stateno = 1021 && animelem = 2, >= 3
trigger3 = stateno = 1022 && animelem = 3, >= 3

;---------------------------------------------------------------------------
;Dive (Weak Kick)
[State -1, Dive]
type = ChangeState
value = 1030
triggerall = var(59) = 0
triggerall = command = "DP_a"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = [200,499]

;---------------------------------------------------------------------------
;Dive (Medium Kick)
[State -1, Dive]
type = ChangeState
value = 1031
triggerall = var(59) = 0
triggerall = command = "DP_b"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = [200,499]

;---------------------------------------------------------------------------
;Dive (Strong Kick)
[State -1, Dive]
type = ChangeState
value = 1032
triggerall = var(59) = 0
triggerall = command = "DP_c"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = [200,499]

;---------------------------------------------------------------------------
;Repeating Punch (Weak Punch)
[State -1, Repeating Punch]
type = ChangeState
value = 1010
triggerall = var(59) = 0
triggerall = command = "QCF_x"
trigger1 = statetype != C
trigger1 = ctrl
trigger2 = stateno = [200,699]

;---------------------------------------------------------------------------
;Repeating Punch (Medium Punch)
[State -1, Repeating Punch]
type = ChangeState
value = 1011
triggerall = var(59) = 0
triggerall = command = "QCF_y"
trigger1 = statetype != C
trigger1 = ctrl
trigger2 = stateno = [200,699]

;---------------------------------------------------------------------------
;Repeating Punch (Strong Punch)
[State -1, Repeating Punch]
type = ChangeState
value = 1012
triggerall = var(59) = 0
triggerall = command = "QCF_z"
trigger1 = statetype != C
trigger1 = ctrl
trigger2 = stateno = [200,699]

;===========================================================================
;Stolen Moves
;===========================================================================
;---------------------------------------------------------------------------
; Hadouken (Weak Punch) (Ryu)
[State -1]
type = ChangeState
value = 2010
triggerall = var(59) = 0
triggerall = var(0) = 2
triggerall = command = "QCF_a"
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = [200,499]

;---------------------------------------------------------------------------
; Hadouken (Medium Punch) (Ryu)
[State -1]
type = ChangeState
value = 2011
triggerall = var(59) = 0
triggerall = var(0) = 2
triggerall = command = "QCF_b"
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = [200,499]

;---------------------------------------------------------------------------
; Hadouken (Strong Punch) (Ryu)
[State -1]
type = ChangeState
value = 2012
triggerall = var(59) = 0
triggerall = var(0) = 2
triggerall = command = "QCF_c"
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = [200,250]) || (stateno = [400,450]) ;Regular Attacks
trigger2 = movecontact = 1

;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
triggerall = var(59) = 0
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = stateno != 100
trigger1 = ctrl

;---------------------------------------------------------------------------
;Air Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 102
triggerall = var(59) = 0
trigger1 = command = "FF"
trigger1 = Pos Y <= -70
trigger1 = statetype = A
trigger1 = stateno != 102
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
[State -1, Run Back]
type = ChangeState
value = 105
triggerall = var(59) = 0
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = stateno != 105
trigger1 = ctrl

;---------------------------------------------------------------------------
;Rising Throw
[State -1, Rising Throw]
type = ChangeState
value = 800
triggerall = var(59) = 0
triggerall = (command = "y") || (command = "z")
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 4
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 6
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H

;===========================================================================
;---------------------------------------------------------------------------
;Super Jump
[State -1, Super Jump]
type = ChangeState
value = 65
triggerall = var(59) = 0
triggerall = Pos Y = 0
trigger1 = ctrl
trigger1 = command = "DU"
trigger2 = command = "holdup"
trigger2 = stateno = 250
trigger2 = MoveHit
trigger3 = command = "holdup"
trigger3 = stateno = 420
trigger3 = MoveHit

;===========================================================================
;---------------------------------------------------------------------------
;Guard Push (Stand)
[State -1, Guard Push (Stand)]
type = ChangeState
value = 160
triggerall = var(59) = 0
trigger1 = command = "PPP"
trigger1 = statetype = S
trigger1 = stateno = 150
ignorehitpause = 1

;---------------------------------------------------------------------------
;Guard Push (Crouch)
[State -1, Guard Push (Crouch)]
type = ChangeState
value = 161
triggerall = var(59) = 0
trigger1 = command = "PPP"
trigger1 = statetype = C
trigger1 = stateno = 152
ignorehitpause = 1

;---------------------------------------------------------------------------
;Guard Push (Air)
[State -1, Guard Push (Air)]
type = ChangeState
value = 162
triggerall = var(59) = 0
trigger1 = command = "PPP"
trigger1 = statetype = A
trigger1 = stateno = 154
ignorehitpause = 1

;===========================================================================
;---------------------------------------------------------------------------
;Stand Light Punch
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = var(59) = 0
trigger1 = command = "x"
trigger1 = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Stand Medium Punch
[State -1, Stand Medium Punch]
type = ChangeState
value = 210
triggerall = var(59) = 0
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && MoveContact
trigger3 = (stateno = 230) && MoveContact
trigger4 = (stateno = 400) && MoveContact
trigger5 = (stateno = 430) && MoveContact

;---------------------------------------------------------------------------
;Stand Strong Punch
[State -1, Stand Strong Punch]
type = ChangeState
value = 220
triggerall = var(59) = 0
triggerall = command = "z"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && MoveContact
trigger3 = (stateno = 210) && MoveContact
trigger4 = (stateno = 230) && MoveContact
trigger5 = (stateno = 240) && MoveContact
trigger6 = (stateno = 400) && MoveContact
trigger7 = (stateno = 410) && MoveContact
trigger8 = (stateno = 430) && MoveContact
trigger9 = (stateno = 440) && MoveContact

;---------------------------------------------------------------------------
;Stand Light Kick
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = var(59) = 0
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && MoveContact
trigger3 = (stateno = 400) && MoveContact

;---------------------------------------------------------------------------
;Standing Medium Kick
[State -1, Standing Medium Kick]
type = ChangeState
value = 240
triggerall = var(59) = 0
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && MoveContact
trigger3 = (stateno = 210) && MoveContact
trigger4 = (stateno = 230) && MoveContact
trigger5 = (stateno = 400) && MoveContact
trigger6 = (stateno = 410) && MoveContact
trigger7 = (stateno = 430) && MoveContact

;---------------------------------------------------------------------------
;Standing Strong Kick
[State -1, Standing Strong Kick]
type = ChangeState
value = 250
triggerall = var(59) = 0
triggerall = command = "c"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && MoveContact
trigger3 = (stateno = 210) && MoveContact
trigger4 = (stateno = 220) && MoveContact
trigger5 = (stateno = 230) && MoveContact
trigger6 = (stateno = 240) && MoveContact
trigger7 = (stateno = 400) && MoveContact
trigger8 = (stateno = 410) && MoveContact
trigger9 = (stateno = 430) && MoveContact
trigger10 = (stateno = 440) && MoveContact

;---------------------------------------------------------------------------
;Taunt
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = var(59) = 0
triggerall = command = "start"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Light Punch
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = var(59) = 0
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Medium Punch
[State -1, Crouching Medium Punch]
type = ChangeState
value = 410
triggerall = var(59) = 0
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200) && MoveContact
trigger3 = (stateno = 230) && MoveContact
trigger4 = (stateno = 400) && MoveContact
trigger5 = (stateno = 430) && MoveContact

;---------------------------------------------------------------------------
;Crouching Strong Punch
[State -1, Crouching Strong Punch]
type = ChangeState
value = 420
triggerall = var(59) = 0
triggerall = command = "z"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200) && MoveContact
trigger3 = (stateno = 210) && MoveContact
trigger4 = (stateno = 230) && MoveContact
trigger5 = (stateno = 240) && MoveContact
trigger6 = (stateno = 400) && MoveContact
trigger7 = (stateno = 410) && MoveContact
trigger8 = (stateno = 430) && MoveContact
trigger9 = (stateno = 440) && MoveContact

;---------------------------------------------------------------------------
;Crouching Light Kick
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = var(59) = 0
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200) && MoveContact
trigger3 = (stateno = 400) && MoveContact

;---------------------------------------------------------------------------
;Crouching Medium Kick
[State -1, Crouching Medium Kick]
type = ChangeState
value = 440
triggerall = var(59) = 0
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200) && MoveContact
trigger3 = (stateno = 210) && MoveContact
trigger4 = (stateno = 230) && MoveContact
trigger5 = (stateno = 400) && MoveContact
trigger6 = (stateno = 410) && MoveContact
trigger7 = (stateno = 430) && MoveContact

;---------------------------------------------------------------------------
;Crouching Strong Kick
[State -1, Crouching Strong Kick]
type = ChangeState
value = 450
triggerall = var(59) = 0
triggerall = command = "c"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200) && MoveContact
trigger3 = (stateno = 210) && MoveContact
trigger4 = (stateno = 220) && MoveContact
trigger5 = (stateno = 230) && MoveContact
trigger6 = (stateno = 240) && MoveContact
trigger7 = (stateno = 400) && MoveContact
trigger8 = (stateno = 410) && MoveContact
trigger9 = (stateno = 420) && MoveContact
trigger10 = (stateno = 430) && MoveContact
trigger11 = (stateno = 440) && MoveContact

;---------------------------------------------------------------------------
;Jump Light Punch
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = var(59) = 0
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jump Medium Punch
[State -1, Jump Medium Punch]
type = ChangeState
value = 610
triggerall = var(59) = 0
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600) && MoveContact
trigger3 = (stateno = 630) && MoveContact

;---------------------------------------------------------------------------
;Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 620
triggerall = var(59) = 0
triggerall = command = "z"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600) && MoveContact
trigger3 = (stateno = 610) && MoveContact
trigger4 = (stateno = 630) && MoveContact
trigger5 = (stateno = 640) && MoveContact

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = var(59) = 0
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600) && MoveContact

;---------------------------------------------------------------------------
;Jump Medium Kick
[State -1, Jump Medium Kick]
type = ChangeState
value = 640
triggerall = var(59) = 0
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600) && MoveContact
trigger3 = (stateno = 610) && MoveContact
trigger4 = (stateno = 630) && MoveContact

;---------------------------------------------------------------------------
;Dive Kick
[State -1, Dive Kick]
type = ChangeState
value = 655
triggerall = var(59) = 0
triggerall = command = "c"
triggerall = command = "holddown"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jump Strong Kick
[State -1, Jump Strong Kick]
type = ChangeState
value = 650
triggerall = var(59) = 0
triggerall = command = "c"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600) && MoveContact
trigger3 = (stateno = 610) && MoveContact
trigger4 = (stateno = 620) && MoveContact
trigger5 = (stateno = 630) && MoveContact
trigger6 = (stateno = 640) && MoveContact

;---------------------------------------------------------------------------
;Roll
[State -1, Roll]
type = ChangeState
value = 1040
triggerall = var(59) = 0
triggerall = (stateno = 5101) || (stateno = 5110)
trigger1 = command = "HCF_a"
trigger2 = command = "HCF_b"
trigger3 = command = "HCF_c"
trigger4 = command = "HCF_x"
trigger5 = command = "HCF_y"
trigger6 = command = "HCF_z"